# Sources

There are currently scrapers for 38 of America's 56 states and territories.

| State | Source | Docs | Authors | Tags |
| :---- | :----: | :--: | :------ | :--- |
|[Alabama](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/al.py)|[🔗](https://www.madeinalabama.com/warn-list/)|[📃](scrapers/al.md)|[Dilcia19](https://github.com/Dilcia19), [zstumgoren](https://github.com/zstumgoren)|html|
|[Alaska](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ak.py)|[🔗](https://jobs.alaska.gov/RR/WARN_notices.htm)||[Dilcia19](https://github.com/Dilcia19), [zstumgoren](https://github.com/zstumgoren)|html|
|[Arizona](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/az.py)|[🔗](https://www.azjobconnection.gov/search/warn_lookups/new)|[📃](scrapers/az.md)|[Dilcia19](https://github.com/Dilcia19), [zstumgoren](https://github.com/zstumgoren)|jobcenter|
|[California](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ca.py)|[🔗](https://edd.ca.gov/en/Jobs_and_Training/Layoff_Services_WARN)|[📃](scrapers/ca.md)|[Dilcia19](https://github.com/Dilcia19), [ydoc5212](https://github.com/ydoc5212), [zstumgoren](https://github.com/zstumgoren)|excel, html, pdf|
|[Connecticut](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ct.py)|[🔗](https://www.ctdol.state.ct.us/progsupt/bussrvce/warnreports/warnreports.htm)||[Dilcia19](https://github.com/Dilcia19), [stucka](https://github.com/stucka), [zstumgoren](https://github.com/zstumgoren)|html|
|[Delaware](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/de.py)|[🔗](https://joblink.delaware.gov/search/warn_lookups/new)|[📃](scrapers/de.md)|[Dilcia19](https://github.com/Dilcia19), [zstumgoren](https://github.com/zstumgoren)|jobcenter|
|[Florida](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/fl.py)|[🔗](http://floridajobs.org/office-directory/division-of-workforce-services/workforce-programs/reemployment-and-emergency-assistance-coordination-team-react/warn-notices)||[Dilcia19](https://github.com/Dilcia19), [shallotly](https://github.com/shallotly), [zstumgoren](https://github.com/zstumgoren)|html, pdf|
|[Georgia](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ga.py)|[🔗](https://www.dol.state.ga.us/public/es/warn/searchwarns/list)||[chriszs](https://github.com/chriszs)|html|
|[Idaho](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/id.py)|[🔗](https://www.labor.idaho.gov/dnn/Businesses/Layoff-Assistance#2)||[chriszs](https://github.com/chriszs)|pdf|
|[Illinois](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/il.py)|[🔗](https://www2.illinois.gov/dceo/WorkforceDevelopment/warn/Pages/default.aspx)||[chriszs](https://github.com/chriszs)|excel, html|
|[Indiana](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/in.py)|[🔗](https://www.in.gov/dwd/2567.htm)|[📃](scrapers/in.md)|[Dilcia19](https://github.com/Dilcia19), [zstumgoren](https://github.com/zstumgoren)|html|
|[Iowa](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ia.py)|[🔗](https://www.iowaworkforcedevelopment.gov/worker-adjustment-and-retraining-notification-act)|[📃](scrapers/ia.md)|[Dilcia19](https://github.com/Dilcia19), [palewire](https://github.com/palewire), [shallotly](https://github.com/shallotly), [zstumgoren](https://github.com/zstumgoren)|excel, html|
|[Kansas](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ks.py)|[🔗](https://www.kansasworks.com/search/warn_lookups/new)|[📃](scrapers/ks.md)|[Dilcia19](https://github.com/Dilcia19), [zstumgoren](https://github.com/zstumgoren)|jobcenter|
|[Kentucky](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ky.py)|[🔗](https://kcc.ky.gov/employer/Pages/Business-Downsizing-Assistance---WARN.aspx)||[palewire](https://github.com/palewire)|excel|
|[Louisiana](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/la.py)|[🔗](https://www.laworks.net/Downloads/Downloads_WFD.asp)||[chriszs](https://github.com/chriszs)|html, pdf|
|[Maine](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/me.py)|[🔗](https://joblink.maine.gov/search/warn_lookups/new)|[📃](scrapers/me.md)|[zstumgoren](https://github.com/zstumgoren)|jobcenter|
|[Maryland](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/md.py)|[🔗](http://www.dllr.state.md.us/employment/warn.shtml)|[📃](scrapers/md.md)|[Dilcia19](https://github.com/Dilcia19), [shallotly](https://github.com/shallotly), [zstumgoren](https://github.com/zstumgoren)|html|
|[Michigan](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/mi.py)|[🔗](https://milmi.org/warn/)||[anikasikka](https://github.com/anikasikka)|html, pdf|
|[Missouri](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/mo.py)|[🔗](https://jobs.mo.gov/content/2022-warn-notices)|[📃](scrapers/mo.md)|[Dilcia19](https://github.com/Dilcia19), [shallotly](https://github.com/shallotly), [zstumgoren](https://github.com/zstumgoren)|html|
|[Montana](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/mt.py)|[🔗](https://wsd.dli.mt.gov/wioa/related-links/warn-notice-page)||[ydoc5212](https://github.com/ydoc5212), [zstumgoren](https://github.com/zstumgoren)|excel, html|
|[Nebraska](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ne.py)|[🔗](https://dol.nebraska.gov/ReemploymentServices/LayoffServices/LayoffsAndDownsizingWARN)||[Dilcia19](https://github.com/Dilcia19), [zstumgoren](https://github.com/zstumgoren)|html|
|[New Jersey](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/nj.py)|[🔗](https://www.nj.gov/labor/employer-services/warn/)||[Dilcia19](https://github.com/Dilcia19), [palewire](https://github.com/palewire), [zstumgoren](https://github.com/zstumgoren)|html|
|[New Mexico](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/nm.py)|[🔗](https://www.dws.state.nm.us/Rapid-Response)||[chriszs](https://github.com/chriszs)|pdf|
|[New York](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ny.py)|[🔗](https://dol.ny.gov/warn-notices)|[📃](scrapers/ny.md)|[Dilcia19](https://github.com/Dilcia19), [ydoc5212](https://github.com/ydoc5212), [zstumgoren](https://github.com/zstumgoren)|excel, historical|
|[Ohio](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/oh.py)|[🔗](https://jfs.ohio.gov/warn/index.stm)||[Dilcia19](https://github.com/Dilcia19), [chriszs](https://github.com/chriszs), [zstumgoren](https://github.com/zstumgoren)|html, pdf|
|[Oklahoma](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ok.py)|[🔗](https://okjobmatch.com/search/warn_lookups/new)|[📃](scrapers/ok.md)|[Dilcia19](https://github.com/Dilcia19), [zstumgoren](https://github.com/zstumgoren)|jobcenter|
|[Oregon](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/or.py)|[🔗](https://ccwd.hecc.oregon.gov/Layoff/WARN)|[📃](scrapers/or.md)|[Dilcia19](https://github.com/Dilcia19), [ydoc5212](https://github.com/ydoc5212), [zstumgoren](https://github.com/zstumgoren)|excel, historical|
|[Rhode Island](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ri.py)|[🔗](https://dlt.ri.gov/employers/worker-adjustment-and-retraining-notification-warn)||[Dilcia19](https://github.com/Dilcia19), [chriszs](https://github.com/chriszs), [ydoc5212](https://github.com/ydoc5212), [zstumgoren](https://github.com/zstumgoren)|excel|
|[South Carolina](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/sc.py)|[🔗](https://scworks.org/employer/employer-programs/at-risk-of-closing/layoff-notification-reports)|[📃](scrapers/sc.md)|[palewire](https://github.com/palewire)|html, pdf|
|[South Dakota](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/sd.py)|[🔗](https://dlr.sd.gov/workforce_services/businesses/warn_notices.aspx)||[Dilcia19](https://github.com/Dilcia19), [ydoc5212](https://github.com/ydoc5212), [zstumgoren](https://github.com/zstumgoren)|html|
|[Tennessee](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/tn.py)|[🔗](https://www.tn.gov/workforce/general-resources/major-publications0/major-publications-redirect/reports.html)||[anikasikka](https://github.com/anikasikka)|html, pdf|
|[Texas](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/tx.py)|[🔗](https://www.twc.texas.gov/businesses/worker-adjustment-and-retraining-notification-warn-notices#warnNotices)|[📃](scrapers/tx.md)|[Dilcia19](https://github.com/Dilcia19), [ydoc5212](https://github.com/ydoc5212)|excel, historical, html|
|[Utah](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/ut.py)|[🔗](https://jobs.utah.gov/employer/business/warnnotices.html)|[📃](scrapers/ut.md)|[Dilcia19](https://github.com/Dilcia19), [zstumgoren](https://github.com/zstumgoren)|html|
|[Vermont](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/vt.py)|[🔗](https://www.vermontjoblink.com/search/warn_lookups/new)|[📃](scrapers/vt.md)|[zstumgoren](https://github.com/zstumgoren)|jobcenter|
|[Virginia](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/va.py)|[🔗](https://www.vec.virginia.gov/warn-notices)|[📃](scrapers/va.md)|[Dilcia19](https://github.com/Dilcia19), [shallotly](https://github.com/shallotly), [zstumgoren](https://github.com/zstumgoren)|csv, html|
|[Washington](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/wa.py)|[🔗](https://esd.wa.gov/about-employees/WARN)||[Dilcia19](https://github.com/Dilcia19), [zstumgoren](https://github.com/zstumgoren)|html|
|[Wisconsin](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/wi.py)|[🔗](https://dwd.wisconsin.gov/dislocatedworker/warn/)|[📃](scrapers/wi.md)|[Dilcia19](https://github.com/Dilcia19), [ydoc5212](https://github.com/ydoc5212), [zstumgoren](https://github.com/zstumgoren)|html|
|[District of Columbia](https://github.com/biglocalnews/warn-scraper/blob/main/warn/scrapers/dc.py)|[🔗](https://does.dc.gov/page/industry-closings-and-layoffs-warn-notifications-2022)|[📃](scrapers/dc.md)|[Dilcia19](https://github.com/Dilcia19), [shallotly](https://github.com/shallotly), [zstumgoren](https://github.com/zstumgoren)|html|


## To do

These 18 areas need a scraper:

- Arkansas
- Colorado
- Hawaii
- Massachusetts
- Minnesota
- Mississippi
- Nevada
- New Hampshire
- North Carolina
- North Dakota
- Pennsylvania
- West Virginia
- Wyoming
- American Samoa
- Guam
- Northern Mariana Islands
- Puerto Rico
- Virgin Islands
